<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
  xmlns:xlink="http://www.w3.org/1999/xlink"
  xmlns="http://docbook.org/ns/docbook" xmlns:db="http://docbook.org/ns/docbook">
  
  <xsl:import href="../../docbook-xsl/xhtml/chunk.xsl"/>
  <xsl:include href="common.xsl"/>
  <xsl:include href="slideReference.xsl"/>
  
  <xsl:output indent="no"/>
  
  <xsl:template match="@* | node()">
    <xsl:copy>
      <xsl:apply-templates select="node()| @*"/>
    </xsl:copy>
  </xsl:template>
  
  
  <xsl:template match="db:chapter/db:title | db:section/db:title">
    <xsl:copy-of select="."/>
    <xsl:for-each select="parent::*[contains(@annotations, 'slide') or descendant::*[contains(@annotations, 'slide')]]">
        <para>
          <link xlink:href="__slide{@xml:id}.html">Related slides on offer</link>
        </para>
    </xsl:for-each>
    
  </xsl:template>
  
  <xsl:template match="db:figure/db:title">
    <xsl:variable name="slideContainerId" select="ancestor::*[contains(@annotations, 'slide')]/@xml:id"/>
    
    <title>
      <xsl:copy-of select="text()|*"/>

      <xsl:if test="$slideContainerId">
        <xsl:text> </xsl:text>
        
        <xsl:variable name="htmlPresentationLinkFileBasename">
          <xsl:text>__figurelink</xsl:text>
          <xsl:value-of select="generate-id()"/>
          <xsl:text>.html</xsl:text>
        </xsl:variable>
        
        <xsl:variable name="htmlPresentationLinkFilename">
          <xsl:if test="ancestor::*/@xml:base">
            <xsl:call-template name="hdm.get.leftmost.of.separator">
              <xsl:with-param name="path">
                <xsl:value-of select="ancestor::*/@xml:base"/>
              </xsl:with-param>
              <xsl:with-param name="separator">/</xsl:with-param>
            </xsl:call-template>
            <xsl:text>/</xsl:text>
          </xsl:if>
          <xsl:value-of select="$htmlPresentationLinkFileBasename"/>
        </xsl:variable>

        <!--
          Hack circumventing docbook XSL bug https://sourceforge.net/p/docbook/bugs/1399
          preventing nesting of <inlinemediaobject> descendants inside <figure>/<title>.
        -->
      
        <xsl:result-document href="target/profile/{$htmlPresentationLinkFilename}" method="html" encoding="utf-8" indent="no">
          <a>
            <xsl:attribute name="href">
              <xsl:call-template name="slideReference">
                <xsl:with-param name="slideContainerId" select="$slideContainerId"/>
                <xsl:with-param name="slideObjectId" select="parent::db:figure/@xml:id"/>
              </xsl:call-template>
            </xsl:attribute>
            <img style="vertical-align: middle;" src="common/images/presentation.svg" width="30"/>
          </a>
        </xsl:result-document>
        
        <xsl:processing-instruction name="dbhtml-include">
          <xsl:text>href="</xsl:text>
          <xsl:value-of select="$htmlPresentationLinkFileBasename"/>
          <xsl:text>"</xsl:text>
        </xsl:processing-instruction>
       
      </xsl:if>
    </title>
    
    <xsl:if test="not($slideContainerId) and ends-with(parent::db:figure/db:mediaobject/db:imageobject/db:imagedata/@fileref, '.fig')">
      <para>
        <uri>
          <xsl:attribute name="xlink:href">
            <xsl:call-template name="hdm.get.leftmost.of.separator">
              <xsl:with-param name="path">
                <xsl:call-template name="relative-uri">
                  <xsl:with-param name="filename" select="parent::db:figure/db:mediaobject/db:imageobject/db:imagedata/@fileref"/>
                </xsl:call-template>
              </xsl:with-param> 
              <xsl:with-param name="separator" select="'.'"/>
            </xsl:call-template>                  
            <xsl:text>.animate.pdf</xsl:text>
          </xsl:attribute>
          <xsl:text>(Animated PDF Version)</xsl:text>
        </uri>
      </para>
    </xsl:if>
    
    <xsl:if test="not($slideContainerId) and ends-with(parent::db:figure/db:mediaobject/db:imageobject/db:imagedata/@fileref, '.svg')">
      <para>
        <uri>
          <xsl:attribute name="xlink:href">
            <xsl:call-template name="relative-uri">
              <xsl:with-param name="filename" select="parent::db:figure/db:mediaobject/db:imageobject/db:imagedata/@fileref"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:text>Separate SVG image link</xsl:text>
        </uri>
      </para>
    </xsl:if>
    
  </xsl:template>
  
  <xsl:template match="db:imagedata[ends-with(@fileref, '.fig')]">   
    <xsl:copy>
      <xsl:attribute name="fileref">
        <xsl:value-of select="@fileref"/>
        <xsl:text>.svg</xsl:text>
      </xsl:attribute>
      <xsl:apply-templates select="@*[not(name(.) = 'fileref')] | node()"/>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="db:imagedata[ends-with(@fileref, '.pdf')]">   
    <xsl:copy>
      <xsl:attribute name="fileref">
        <xsl:value-of select="@fileref"/>
        <xsl:text>.svg</xsl:text>
      </xsl:attribute>
      <xsl:apply-templates select="@*[not(name(.) = 'fileref')] | node()"/>
    </xsl:copy>
  </xsl:template>
  
</xsl:stylesheet>
