<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
  xmlns:xlink="http://www.w3.org/1999/xlink"
  xmlns="http://docbook.org/ns/docbook" xmlns:d="http://docbook.org/ns/docbook">
  
  
  <xsl:import href="../../docbook-xsl/xhtml/chunk.xsl"/>
  
  <xsl:include href="common.xsl"/>
  
  <xsl:template match="/">
    
    <xsl:variable name="figFiles" select="//d:imagedata[ends-with(@fileref, '.fig') ]" />
    <xsl:variable name="pdfFiles" select="//d:imagedata[ends-with(@fileref, '.pdf') ]" />
    
    <xsl:apply-templates select="//d:imagedata[ends-with(@fileref, '.fig') ]" mode="printLatex"/>
    
    <xsl:result-document method="text" encoding="utf-8" href="mediaobjects.list" >
      <xsl:text>all: </xsl:text>
      
      <xsl:for-each select="$figFiles">
        <xsl:call-template name="relative-uri">
          <xsl:with-param name="destdir">
            <xsl:call-template name="dbhtml-dir">
              <xsl:with-param name="context" select="."/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
        
        <xsl:value-of select="@fileref"/>
        <xsl:text>.pdf </xsl:text>
      </xsl:for-each>
      
      <xsl:for-each select="$pdfFiles">
        <xsl:call-template name="relative-uri">
          <xsl:with-param name="destdir">
            <xsl:call-template name="dbhtml-dir">
              <xsl:with-param name="context" select="."/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
        
        <xsl:value-of select="@fileref"/>
        <xsl:text>.svg </xsl:text>
      </xsl:for-each>
      
      <xsl:for-each select="//d:videodata[ends-with(@fileref, '.webm') ]">
        <xsl:call-template name="relative-uri">
          <xsl:with-param name="destdir">
            <xsl:call-template name="dbhtml-dir">
              <xsl:with-param name="context" select="."/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
        <xsl:value-of select="@fileref"/>
        <xsl:text>.mp4 </xsl:text>
      </xsl:for-each>
      
    </xsl:result-document>
  </xsl:template>
  
  <xsl:template match="d:imagedata" mode="printLatex">
    
    <xsl:variable name="dirPath">
      <xsl:call-template name="hdm.get.leftmost.of.separator">
        <xsl:with-param name="path" select="@fileref"/>
        <xsl:with-param name="separator" select="'/'"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="fileName">
      <xsl:call-template name="hdm.get.pure.filename">
        <xsl:with-param name="path" select="@fileref"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="fileBaseName">
      <xsl:call-template name="hdm.get.leftmost.of.separator">
        <xsl:with-param name="path" select="$fileName"/>
        <xsl:with-param name="separator" select="'.'"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="fullGenerateBasename" >
      <xsl:call-template name="relative-uri">
        <xsl:with-param name="destdir">
          <xsl:call-template name="dbhtml-dir">
            <xsl:with-param name="context" select="."/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:value-of select="$dirPath"/>
      <xsl:text>/Generate/</xsl:text>
      <xsl:value-of select="$fileBaseName"/>
    </xsl:variable>
    
    
    <xsl:value-of select="$fullGenerateBasename"/>
    <xsl:text>.tex
    </xsl:text>
    
    <xsl:result-document method="text" encoding="utf-8" href="{$fullGenerateBasename}.tex" >
      <xsl:text>\input{/usr/share/hdm-docbook-xsl/Preprocess/pre.tex} 
        \begin{mycenterframe}{</xsl:text>
      <xsl:apply-templates select="." mode="object.title.markup.textonly"/>
      <xsl:text>}
        \multifigure{Generate/</xsl:text>
      <xsl:value-of select="$fileBaseName" />
      <xsl:text>}
        \end{mycenterframe}
        \end{document}
      </xsl:text>
    </xsl:result-document>
  </xsl:template>
  
  <xsl:template name="hdm.get.pure.filename">
    <!-- Stripping a filename path from all directory components -->
    <xsl:param name="path"/>
    <xsl:choose>
      <xsl:when test="contains($path, '/' )">
        <xsl:call-template name="hdm.get.pure.filename">
          <xsl:with-param name="path">
            <xsl:value-of select="substring-after($path, '/')"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$path"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
</xsl:stylesheet>
